<?php
/**
 * Instagram widget.
 *
 * @package Moon
 * @since   1.0.0
 */

class NQ_Moon_Widget_Instagram extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'description' => __( 'Show off your favorite Instagram photos', 'moon' )
		);
		$control_ops = array(
			'width'  => 'auto',
			'height' => 'auto'
		);
		parent::__construct( 'moon_instagram', __( 'Moon - Instagram', 'moon' ), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title   = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$id      = empty($instance['id']) ? '' : $instance['id'];
		$token   = empty($instance['token']) ? '' : $instance['token'];
		$limit   = empty( $instance['limit'] ) ? 4 : ( int ) $instance['limit'];
		$columns = empty( $instance['columns'] ) ? 2 : ( int ) $instance['columns'];

		if ( ! ( $id && $token ) ) return;

		echo $before_widget;
		
		if ( ! empty( $title ) ) {
			echo $before_title . $title . $after_title;
		}
		if ( intval( $id ) === 0 ) {
			echo '<p>No user ID specified.</p>';
		}
		
		$transient_var = $id . '_' . $limit;
		
		if ( false === ( $items = get_transient( $transient_var ) ) ) {
		
			$response = wp_remote_get( 'https://api.instagram.com/v1/users/' . esc_attr( $id ) . '/media/recent/?access_token=' . esc_attr( $token ) . '&count=' . esc_attr( $limit ) );
		
			$response_body = json_decode( $response['body'] );
			
			if ( $response_body->meta->code !== 200 ) {
				echo '<p>Incorrect user ID specified.</p>';
			}
			
			$items_as_objects = $response_body->data;
			$items = array();
			foreach ( $items_as_objects as $item_object ) {
				$item['link'] = $item_object->link;
				$item['src']  = $item_object->images->low_resolution->url;
				$items[]      = $item;
			}
			
			set_transient( $transient_var, $items, 60 * 60 );
		}
		
		$output = '<div class="instagram clear cols-' . esc_attr( $columns ) . '">';
		
		if ( isset( $items ) ) {
			foreach ( $items as $item ) {
				$link	= $item['link'];
				$image	= $item['src'];
				$output	.= '<div class="item"><a href="' . esc_url( $link ) .'"><img width="320" height="320" src="' . esc_url( $image ) . '" alt="Instagram" /></a></div>';
			}
		}
		
		$output .= '</div>';

		echo $output . $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = array();
		if ( ! empty( $new_instance['title'] ) ) {
			$instance['title'] = sanitize_text_field( $new_instance['title'] );
		}
		if ( ! empty( $new_instance['id'] ) ) {
			$instance['id'] =  sanitize_text_field( $new_instance['id'] );
		}
		if ( ! empty( $new_instance[''] ) ) {
			$instance[''] =  sanitize_text_field( $new_instance[''] );
		}
		if ( ! empty( $new_instance['limit'] ) ) {
			$instance['limit'] =  ( int ) $new_instance['limit'];
		}
		if ( ! empty( $new_instance['columns'] ) ) {
			$instance['columns'] = ( int ) $new_instance['columns'];
		}
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array( 'title' => '', 'id' => '', 'limit' => 4, 'columns' => 2 ) );
		$title    = strip_tags( $instance['title'] );
		$id       = isset( $instance['id'] ) ? $instance['id'] : '';
		$token    = isset( $instance['token'] ) ? $instance['token'] : '';
		$limit    = ( int ) $instance['limit'];
		$columns  = ( int ) $instance['columns'];

		$url_id    = 'https://smashballoon.com/instagram-feed/find-instagram-user-id/';
		$url_token = 'http://instagram.pixelunion.net/';
	?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'id' ) ); ?>"><?php printf( wp_kses( __( 'Instagram user ID (<a target="_blank" href="%1$s">Lookup your User ID</a>)', 'moon' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( $url_id ) ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'id' ) ); ?>" type="text" value="<?php echo esc_attr( $id ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'token' ) ); ?>"><?php printf( wp_kses_post( 'Instagram Access Token (<a href="%s" target="_blank">Lookup your Access Token</a>)', 'moon' ), $url_token ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'token' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'token' ) ); ?>" type="text" value="<?php echo esc_attr( $token ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>"><?php _e( 'Number of Photos:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'limit' ) ); ?>" type="number" min="1" value="<?php echo esc_attr( $limit ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php _e( 'Columns (1-5):', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>" type="number" min="1" max="5" step="1" value="<?php echo esc_attr( $columns ); ?>" />
		</p>

	<?php
	}
}