<?php
/**
 * Tabs widget.
 *
 * @package Moon
 * @since   1.0.0
 */

class NQ_Moon_Widget_Tabs extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'description' => __( 'Displays the popular and the recent posts in tab', 'moon' )
		);
		$control_ops = array(
			'width'  => 'auto',
			'height' => 'auto'
		);
		parent::__construct( 'moon_tabs', __( 'Moon - Tabs', 'moon' ), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title        = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$pop          = empty( $instance['pop'] ) ? '' : $instance['pop'];
		$poplimit     = empty( $instance['poplimit'] ) ? '' : $instance['poplimit'];
		$recent       = empty( $instance['recent'] ) ? '' : $instance['recent'];
		$recentlimit  = empty( $instance['recentlimit'] ) ? '' : $instance['recentlimit'];

		echo $before_widget;

		if ( ! empty( $title ) ) {
			echo $before_title . $title . $after_title;
		}
	?>
		<ul class="tabs">
			<?php
				if ( ! empty( $pop ) ) {
				   echo '<li class="active" data-tab="tab-popular">' . esc_html( $pop ) . '</li>';
				}
				if ( ! empty( $recent ) ) {
				   echo '<li data-tab="tab-recent">' . esc_html( $recent ) . '</li>';
				}
			?>
		</ul><!-- .tabs -->

		<div class="tab-content">
			<?php if ( ! empty( $pop ) ) : ?>
				<div id="tab-popular" class="tab-pane active">
				<?php
					$popular = new WP_Query(
						array(
							'post_type'      => 'post',
							'posts_per_page' => $poplimit,
							'orderby'        => 'comment_count',
							'order'          => 'DESC'
						)
					);

					$output = '';

					while ( $popular->have_posts() ) :
						$popular->the_post();

						$num_comments   = get_comments_number();
						$thumbnail_link = wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) );
						$image          = aq_resize( $thumbnail_link, 61, 61, true );

						$output .= '<div class="post-item">';
						if ( has_post_thumbnail() ) :
							$output .= '<img src="' . esc_url( $image ) . '" alt="' . esc_attr( get_the_title() ) . '" width="61" height="61" />';
						endif;
						$output .= '<div class="post-title">';
							$output .= '<h5><a href="' . esc_url( get_permalink() ) . '">' . get_the_title() . '</a></h5>';
							$output .= '<span>';
							if ( $num_comments == 0 ) {
								$comments = __( '0 Comment', 'moon' );
							} elseif ( $num_comments > 1 ) {
								$comments = $num_comments . __( ' Comments', 'moon' );
							} else {
								$comments = __( '1 Comment', 'moon' );
							}
							$output .= '<a href="' . esc_url( get_comments_link() ) . '">' . $comments . '</a>';
							$output .= '</span>';
						$output .= '</div>';
						$output .= '</div>';

					endwhile;
					wp_reset_postdata();

					echo $output;
				?>
				</div><!-- #tab-popular -->
			<?php
				endif;

			if ( ! empty( $recent ) ) : ?>
				<div id="tab-recent" class="tab-pane">
				<?php
					$recent = new WP_Query(
						array(
							'post_type'      => 'post',
							'posts_per_page' => $recentlimit,
							'orderby'        => 'date',
						)
					);

					$output = '';

					while ( $recent->have_posts() ) :
						$recent->the_post();

						$thumbnail_link = wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) );
						$image          = aq_resize( $thumbnail_link, 61, 61, true );

						$output .= '<div class="post-item">';
						if ( has_post_thumbnail() ) :
							$output .= '<img src="' . esc_url( $image ) . '" alt="' . esc_attr( get_the_title() ) . '" width="61" height="61" />';
						endif;
						$output .= '<div class="post-title">';
							$output .= '<h5><a href="' . esc_url( get_permalink() ) . '">' . get_the_title() . '</a></h5>';
							$output .= '<span>' . get_the_time( 'F j, Y' ) . '</span>';
						$output .= '</div>';
						$output .= '</div>';

					endwhile;
					wp_reset_postdata();

					echo $output;
				?>
				</div><!-- #tab-recent -->
			<?php endif; ?>
		</div><!-- .tab-content -->

		<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = array();
		if ( ! empty( $new_instance['title'] ) ) {
			$instance['title'] = sanitize_text_field( $new_instance['title'] );
		}
		if ( ! empty( $new_instance['pop'] ) ) {
			$instance['pop'] =  sanitize_text_field( $new_instance['pop'] );
		}
		if ( ! empty( $new_instance['poplimit'] ) ) {
			$instance['poplimit'] =  ( int ) $new_instance['poplimit'];
		}
		if ( ! empty( $new_instance['recent'] ) ) {
			$instance['recent'] =  sanitize_text_field( $new_instance['recent'] );
		}
		if ( ! empty( $new_instance['recentlimit'] ) ) {
			$instance['recentlimit'] =  ( int ) $new_instance['recentlimit'];
		}
		return $instance;
	}

	function form( $instance ) {
		$instance     = wp_parse_args( ( array ) $instance, array( 'title' => '', 'pop' => 'Popular', 'poplimit' => 5, 'recent' => 'Recent', 'recentlimit' => 5, 'view' => 'Most Viewed', 'viewlimit' => 5 ) );
		$title        = strip_tags( $instance['title'] );
		$pop          = strip_tags( $instance['pop']         );
		$poplimit     = strip_tags( $instance['poplimit']    );
		$recent       = strip_tags( $instance['recent']      );
		$recentlimit  = strip_tags( $instance['recentlimit'] );
	?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'pop' ) ); ?>"><?php _e( 'Porpular Post:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'pop' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'pop' ) ); ?>" type="text" value="<?php echo esc_attr( $pop ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'poplimit' ) ); ?>" style="display: inline;"><?php _e( 'Number Post Display : ', 'moon' );?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'poplimit' ) ); ?>" size="2" name="<?php echo esc_attr( $this->get_field_name( 'poplimit' ) ); ?>" type="text" value="<?php echo esc_attr( $poplimit ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'recent' ) ); ?>"><?php _e( 'Recent posts:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'recent' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'recent' ) ); ?>" type="text" value="<?php echo esc_attr( $recent ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'recentlimit' ) ); ?>" style="display: inline;"><?php _e( 'Number Post Display : ', 'moon' );?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'recentlimit' ) ); ?>" size="2" name="<?php echo esc_attr( $this->get_field_name( 'recentlimit' ) ); ?>" type="text" value="<?php echo esc_attr( $recentlimit ); ?>" />
		</p>

	<?php
	}
}
